Learn R Programming

rockr (version 1.0.0)

rockr.file_download: Download a file

Description

Download a file or a folder from the Rocker R session working directory.

Usage

rockr.file_download(
  conn,
  source,
  destination = NULL,
  overwrite = FALSE,
  temp = FALSE
)

Arguments

conn

A rockr connection object.

source

Path to the file in the R server file system.

destination

Path to the file to be written. If omitted, file with same name in the working directory will be written. Any non-existing parent directories will be created.

overwrite

Overwrite the destination file if TRUE. Default is FALSE.

temp

Logical to specify whether the root folder is the R session's home or the temporary folder. Default is FALSE.

Value

Void

See Also

Other file functions: rockr.file_upload()

Examples

Run this code
# NOT RUN {
conn <- rockr.connect(username='user', password='password',
                      url='https://rocker-demo.obiba.org')
rockr.open(conn)
# download a file
rockr.file_download(conn, 'data.csv')
# download, create destination folder and rename file
rockr.file_download(conn, 'DatabaseTest.sav', 'spss/test.sav')
rockr.close(conn)
# }

Run the code above in your browser using DataLab